@@ -12,6 +12,7 @@ import time
 
 from PySFML import sf
 
+import colores
 import actores
 import imagenes
 import sonidos
@@ -30,6 +31,9 @@ import pilas.utils
 from mundo import Mundo
 from colisiones import Colisiones
 import random
+import ejemplos
+import inspect
+import red
 
 
 # Inicialmente comienza sin un mundo esperando a que se inicialice.
@@ -94,13 +98,23 @@ def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
 
     return clase(valor_o_valores, duracion, demora)
 
+def ver(objeto):
+    "Imprime en pantalla el codigo fuente asociado a un objeto o elemento de pilas."
+
+    if isinstance(objeto, object):
+        codigo = inspect.getsource(objeto.__class__)
+    else:
+        codigo = inspect.getsource(objeto)
+
+    print codigo
+
 
 def avisar(mensaje):
     "Emite un mensaje en la ventana principal."
     texto = actores.Texto(mensaje)
     texto.magnitud = 22
-    texto.izquierda = -320
-    texto.abajo = -240
+    texto.izquierda = -310
+    texto.abajo = -230
 
 def fabricar(clase, cantidad=1):
     "Genera muchas intancias de objetos asignando posiciones aleatorias."
