@@ -32,12 +32,24 @@ def eliminar_a_todos():
     for x in a_eliminar:
         x.eliminar()
 
+def obtener_actor_en(x, y):
+    "Intenta obtener el actor mas cerca de la pantalla (z mas pequeño) en la posición (x, y)"
+
+    # Busca el objeto que colisiones ordenando en sentido inverso.
+    for sprite in todos[::-1]:
+        if sprite.colisiona_con_un_punto(x, y):
+            return sprite
+
+    return None
+
+
 
 class Estudiante:
     "Permite a distintos objetos acoplarse mediente mixins."
 
     def aprender(self, classname, *k, **w):
-        self.__class__.__bases__ += (classname,)
+        if not classname in self.__class__.__bases__:
+            self.__class__.__bases__ += (classname,)
         classname.__init__(self, *k, **w)
 
 
@@ -97,8 +109,18 @@ class BaseActor(object, Estudiante):
         if pilas.utils.es_interpolacion(s):
             s.apply(self, function='set_scale')
         else:
+            if s <= 0:
+                return
+
+            (ultima_escala, _) = self.GetScale()
+
+            # Se hace la siguiente regla de 3 simple:
+            #
+            #  ultima_escala          self.radio_de_colision
+            #  s                      ?
+
             self.SetScale(s, s)
-            self.radio_de_colision = RADIO_INICIAL * s
+            self.radio_de_colision = (s * self.radio_de_colision) / ultima_escala
 
     def get_scale(self):
         # se asume que la escala del personaje es la horizontal.
@@ -153,7 +175,7 @@ class BaseActor(object, Estudiante):
         actores se ven mas arriba de otros cambiando los valores de
         los atributos `z`."""
 
-        if otro_actor.z > self.z:
+        if otro_actor.z >= self.z:
             return 1
         else:
             return -1
@@ -165,29 +187,37 @@ class BaseActor(object, Estudiante):
         self.comportamiento = comportamiento
 
     def get_izquierda(self):
-        rect = self.GetRect()
-        size = (rect.GetWidth(), rect.GetHeight())
-        return self.x - size[0]/2
+        return self.x - self.obtener_ancho()/2
 
     def set_izquierda(self, x):
-        rect = self.GetRect()
-        size = (rect.GetWidth(), rect.GetHeight())
-        self.x = x + size[0]/2
+        self.x = x + self.obtener_ancho()/2
 
     izquierda = property(get_izquierda, set_izquierda)
 
     def get_abajo(self):
-        rect = self.GetRect()
-        size = (rect.GetWidth(), rect.GetHeight())
-        return self.x - size[1]/2
+        return self.y - self.obtener_alto()/2
 
     def set_abajo(self, y):
-        rect = self.GetRect()
-        size = (rect.GetWidth(), rect.GetHeight())
-        self.y = y + size[1]/2
+        self.y = y + self.obtener_alto()/2
 
     abajo = property(get_abajo, set_abajo)
 
+    def get_derecha(self):
+        return self.x + self.obtener_ancho()/2
+
+    def set_derecha(self, x):
+        self.x = x - self.obtener_ancho()/2
+
+    derecha = property(get_derecha, set_derecha)
+
+    def get_arriba(self):
+        return self.y + self.obtener_alto()/2
+
+    def set_arriba(self, y):
+        self.y = y - self.obtener_alto()/2
+
+    arriba = property(get_arriba, set_arriba)
+
 class Actor(sf.Sprite, BaseActor):
     """Representa un objeto visible en pantalla, algo que se ve y tiene posicion.
 
@@ -233,7 +263,7 @@ class Actor(sf.Sprite, BaseActor):
         "Determina si un punto colisiona con el area del actor."
         w, h = self.GetSize()
         left, right = self.x - w/2 , self.x + w/2
-        top, bottom = self.y - h/2, self.y + h/2
+        top, bottom = self.y - h/2,  self.y + h/2
         return left < x < right and top < y < bottom
 
     def dibujar(self, aplicacion):
@@ -247,6 +277,11 @@ class Actor(sf.Sprite, BaseActor):
 
         return duplicado
 
+    def obtener_ancho(self):
+        return self.GetSize()[0]
+
+    def obtener_alto(self):
+        return self.GetSize()[1]
 
 from mono import *
 from tortuga import *
@@ -254,7 +289,9 @@ from texto import *
 from ejes import *
 from pingu import Pingu
 from pizarra import Pizarra
+from animado import Animado
 from animacion import Animacion
 from explosion import Explosion
 from banana import Banana
 from bomba import Bomba
+from moneda import Moneda
