@@ -10,13 +10,6 @@ import pilas
 from pilas.actores import Animacion
 
 class Moneda(Animacion):
-    """Representa una moneda con animación.
-    
-        >>> moneda = pilas.actores.Moneda()
 
-    .. image:: images/actores/moneda.png
-    
-    """
-
-    def __init__(self, x=0, y=0):
-        Animacion.__init__(self, pilas.imagenes.cargar_grilla("moneda.png", 8), ciclica=True, x=x, y=y)
+    def __init__(self):
+        Animacion.__init__(self, pilas.imagenes.Grilla("moneda.png", 8), ciclica=True)
