@@ -52,3 +52,15 @@ class Texto(sf.String, BaseActor):
 
     def dibujar(self, aplicacion):
         aplicacion.Draw(self)
+
+    def colisiona_con_un_punto(self, x, y):
+        return False
+
+    def obtener_ancho(self):
+        rect = self.GetRect()
+        return rect.GetWidth()
+
+    def obtener_alto(self):
+        rect = self.GetRect()
+        return rect.GetHeight()
+
