@@ -10,17 +10,23 @@ from pilas.actores import Actor
 import pilas
 from PySFML import sf
 
-class Escena(Actor):
+class Escena:
     "Escena abstracta."
 
     def __init__(self):
         pilas.mundo.definir_escena(self)
 
+    def iniciar(self):
+        pass
+
     def actualizar(self):
         pass
 
+    def dibujar(self, aplicacion):
+        pass
 
-class Paisaje(Escena):
+
+class Paisaje(Actor, Escena):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
 
     def __init__(self):
@@ -33,7 +39,7 @@ class Normal(Escena):
 
     def __init__(self, color_de_fondo=None):
         Escena.__init__(self)
-        self.fondo = color_de_fondo or sf.Color(200, 200, 200)
+        self.fondo = color_de_fondo or pilas.colores.gris
 
     def dibujar(self, aplicacion):
         aplicacion.Clear(self.fondo)
