@@ -28,7 +28,7 @@ class AumentarConRueda:
         pilas.eventos.mueve_rueda.connect(self.scale_me)
 
     def scale_me(self, sender, delta, signal):
-        self.escala += (delta / 2.0)
+        self.escala += (delta / 4.0)
 
 
 class SeguirClicks:
@@ -43,7 +43,15 @@ class SeguirClicks:
 
 
 class Arrastrable:
-    "Hace que un objeto se pueda arrastrar con el puntero del mouse."
+    """Hace que un objeto se pueda arrastrar con el puntero del mouse.
+
+    Cuando comienza a mover al actor se llama al metodo ''comienza_a_arrastrar''
+    y cuando termina llama a ''termina_de_arrastrar''. Estos nombres
+    de metodos se llaman para que puedas personalizar estos eventos, dado
+    que puedes usar polimorfismo para redefinir el comportamiento
+    de estos dos metodos. Observa un ejemplo de esto en
+    el ejemplo ``pilas.ejemplos.Piezas``.
+    """
 
     def __init__(self):
         pilas.eventos.click_de_mouse.connect(self.try_to_drag)
@@ -53,11 +61,12 @@ class Arrastrable:
 
         if self.colisiona_con_un_punto(x, y):
             pilas.eventos.termina_click.connect(self.drag_end)
-            pilas.eventos.mueve_mouse.connect(self.drag, dispatch_uid='drag')
+            pilas.eventos.mueve_mouse.connect(self.drag, uid='drag')
             self.last_x = x
             self.last_y = y
+            self.comienza_a_arrastrar()
 
-    def drag(self, sender, signal, x, y):
+    def drag(self, sender, signal, x, y, dx, dy):
         "Arrastra el actor a la posicion indicada por el puntero del mouse."
         self.x += x - self.last_x
         self.y += y - self.last_y
@@ -67,8 +76,14 @@ class Arrastrable:
 
     def drag_end(self, sender, signal, x, y, button):
         "Suelta al actor porque se ha soltado el botón del mouse."
-        pilas.eventos.mueve_mouse.disconnect(dispatch_uid='drag')
+        pilas.eventos.mueve_mouse.disconnect(uid='drag')
+        self.termina_de_arrastrar()
 
+    def comienza_a_arrastrar(self):
+        pass
+
+    def termina_de_arrastrar(self):
+        pass
 
 class MoverseConElTeclado:
     "Hace que un actor cambie de posición con pulsar el teclado."
@@ -88,4 +103,3 @@ class MoverseConElTeclado:
             self.y += velocidad
         elif input.IsKeyDown(sf.Key.Down):
             self.y -= velocidad
-
