@@ -57,6 +57,11 @@ class Mundo:
         self.definir_modo_ejecucion(ModoEjecucionNormal(self))
         self.salir = False
 
+        # FIX: tienen la posicion del mouse como memoria para
+        #      obtener los delta e posicion en el evento mueve_mouse.
+        self.mouse_x = 0
+        self.mouse_y = 0
+
     def definir_modo_ejecucion(self, nuevo_modo):
         if self.modo_ejecucion:
             self.modo_ejecucion.salir()
@@ -116,8 +121,6 @@ class Mundo:
 
         self.escena_actual = escena_nueva
 
-        if eliminar_actores:
-            actores.eliminar_a_todos()
 
     def agregar_tarea(self, time_out, function, *params): 
         self.tasks.agregar(time_out, function, params)
@@ -167,8 +170,19 @@ class ModoEjecucionNormal(ModoEjecucion):
 
             elif event.Type == sf.Event.MouseMoved:
                 # Notifica el movimiento del mouse con una señal
-                x, y = self.mundo.ventana.ConvertCoords(event.MouseMove.X, event.MouseMove.Y)
-                eventos.mueve_mouse.send("ejecutar", x=x, y=-y)
+
+                x, y = event.MouseMove.X, event.MouseMove.Y
+
+                if x > 0 and y > 0:
+                    x, y = self.mundo.ventana.ConvertCoords(x, y)
+
+                    dx = x - self.mundo.mouse_x
+                    dy = self.mundo.mouse_y - y
+                    self.mundo.mouse_x = x
+                    self.mundo.mouse_y = y
+
+                    eventos.mueve_mouse.send("ejecutar", x=x, y=-y, dx=dx, dy=dy)
+
             elif event.Type == sf.Event.MouseButtonPressed:
                 x, y = self.mundo.ventana.ConvertCoords(event.MouseButton.X, event.MouseButton.Y)
                 eventos.click_de_mouse.send("ejecutar", button=event.MouseButton.Button, x=x, y=-y)
@@ -235,8 +249,28 @@ class ModoEjecucionDepuracion(ModoEjecucionNormal):
         for actor in actores.todos:
             if actor.radio_de_colision:
                 self.pintar_radio_de_colision_del_actor(actor, color_de_colision, color_borde)
+
             self.pintar_punto_de_control_del_actor(actor, color_de_punto_de_control, color_borde)
 
+            # intenta dibujar el numero de cuadro que usa el actor
+            # si es que tiene una animacion asignada.
+
+            try:
+                cuadro = actor.animacion.obtener_cuadro()
+                self.pintar_numero(cuadro, actor.x, actor.y)
+            except AttributeError, e:
+                pass
+
+
+    def pintar_numero(self, numero, x, y):
+        numero = pilas.actores.Texto(str(numero))
+        numero.x = x
+        numero.y = y
+
+        self.mundo.ventana.Draw(numero)
+        numero.eliminar()
+
+
     def pintar_radio_de_colision_del_actor(self, actor, color, color_borde):
         radio = actor.radio_de_colision *2
         delta = radio / 2
@@ -258,10 +292,12 @@ class ModoEjecucionDepuracion(ModoEjecucionNormal):
         if event.Key.Code == sf.Key.P:
             self.mundo.definir_modo_ejecucion(ModoEjecucionDepuracionPausado(self.mundo))
 
-
     def salir(self):
         self.eje.eliminar()
 
+
+        
+
 class ModoEjecucionDepuracionPausado(ModoEjecucionPausado, ModoEjecucionDepuracion):
 
     def __init__(self, m):
